@@ -477,7 +477,7 @@ class DataFrame(metaclass=DataFrameMeta):
     def read_csv(
         cls: Type[TDataFrame],
         path: Union[str, pathlib.Path],
-        has_header: bool,
+        has_header: bool = True,
         columns: Optional[Union[List[int], List[str], Dict[str, Union[str, Feature, FeatureWrapper, Any]]]] = None,
     ) -> TDataFrame:
         if isinstance(columns, dict):
