@@ -463,6 +463,7 @@ def _process_class(
                         f"'{name}: Windowed[{annotation._kind.__name__}] = windowed('10m', '30m')."
                     )
                 )
+            wind.set_kind(kind=annotation.get_kind())
             wind._name = name
             annotation._buckets = wind._buckets
             for bucket in wind._buckets:
@@ -471,7 +472,7 @@ def _process_class(
                 setattr(cls, feat.name, feat)
                 # For the psuedofeatures, which track an individual bucket, the correct annotation is the
                 # underlying annotation, not Windowed[underlying], since it's only one value
-                cls_annotations[feat.name] = wind._kind
+                cls_annotations[feat.name] = wind.get_kind()
 
         cls_annotations[name] = annotation
 
