@@ -1,6 +1,5 @@
 import importlib
 import importlib.util
-import logging
 import os
 import sys
 import traceback
@@ -10,9 +9,10 @@ from typing import List
 from pydantic import BaseModel
 
 from chalk.gitignore.gitignore_parser import parse_gitignore
+from chalk.utils.log_with_context import get_logger
 from chalk.utils.paths import get_directory_root
 
-_logger = logging.getLogger(__name__)
+_logger = get_logger(__name__)
 
 
 def py_path_to_module(path: Path, repo_root: Path) -> str:
