@@ -3,7 +3,6 @@ from __future__ import annotations
 import collections.abc
 import dataclasses
 import enum
-import logging
 from datetime import date, datetime, timezone
 from typing import TYPE_CHECKING, Any, List, Type, Union, cast, get_origin, get_type_hints
 
@@ -20,6 +19,7 @@ from typing_extensions import get_args
 from chalk.serialization.parsed_annotation import ParsedAnnotation
 from chalk.streams import Windowed
 from chalk.utils.enum import get_enum_value_type
+from chalk.utils.log_with_context import get_logger
 
 if TYPE_CHECKING:
     from chalk.features import Feature
@@ -40,7 +40,7 @@ try:
 except ImportError:
     np = None
 
-_log = logging.getLogger(__name__)
+_log = get_logger(__name__)
 
 _NoneType = type(None)
 
@@ -54,6 +54,21 @@ def _unwrap_optional_if_needed(typ: Type):
     return typ
 
 
+def is_numeric(dtype: Union[pl.DataType, Type[pl.DataType]]) -> bool:
+    return dtype in (
+        pl.Float32,
+        pl.Float64,
+        pl.Int16,
+        pl.Int8,
+        pl.Int32,
+        pl.Int64,
+        pl.UInt8,
+        pl.UInt16,
+        pl.UInt32,
+        pl.UInt64,
+    )
+
+
 class FeatureCodec:
     def __init__(self):
         self.converter = cattrs.Converter()
