@@ -1,4 +1,3 @@
-import logging
 import time
 from collections import defaultdict
 from datetime import datetime
@@ -12,6 +11,7 @@ from chalk.features import DataFrame, Feature, FeatureSetBase
 from chalk.sql.base.protocols import BaseSQLSourceProtocol, ChalkQueryProtocol, DBSessionProtocol, IncrementalSettings
 from chalk.utils.collections import get_unique_item
 from chalk.utils.duration import Duration
+from chalk.utils.log_with_context import get_logger
 from chalk.utils.string import normalize_string_for_matching
 
 
@@ -22,7 +22,7 @@ class Finalizer(str, Enum):
     All = "All"
 
 
-_logger = logging.getLogger(__name__)
+_logger = get_logger(__name__)
 
 # Fancy Python type for Sequence[str] that doesn't match against plain `str`s
 StrSequence = Union[List[str], Tuple[str, ...]]
