@@ -1,6 +1,7 @@
 import inspect
-from typing import Callable, List, Optional, TypeVar, Union
+from typing import Any, Callable, List, Optional, Type, TypeVar, Union
 
+from pydantic import BaseModel
 from typing_extensions import ParamSpec
 
 from chalk.state import KeyedState
@@ -11,18 +12,22 @@ from chalk.streams.base import StreamSource
 from chalk.utils import MachineType
 
 __all__ = [
-    "get_name_with_duration",
-    "get_duration_secs",
     "FileSource",
     "KafkaSource",
-    "Windowed",
-    "windowed",
+    "KeyedState",
     "StreamSource",
+    "Windowed",
+    "stream",
+    "windowed",
+    "get_name_with_duration",
+    "get_duration_secs",
 ]
 
 P = ParamSpec("P")
 T = TypeVar("T")
 
+MessageType = TypeVar("MessageType", bound=BaseModel)
+
 
 def stream(
     *,
@@ -30,6 +35,7 @@ def stream(
     mode: Optional[str] = None,
     environment: Optional[Union[List[str], str]] = None,
     machine_type: Optional[MachineType] = None,
+    message: Optional[Type[Any]] = None,
 ) -> Callable[[Callable[P, T]], Callable[P, T]]:
     caller_frame = inspect.stack()[1]
     caller_filename = caller_frame.filename
@@ -47,17 +53,7 @@ def stream(
             caller_filename=caller_filename,
             environment=environment,
             machine_type=machine_type,
+            message=message,
         )
 
     return decorator
-
-
-__all__ = [
-    "FileSource",
-    "KafkaSource",
-    "KeyedState",
-    "StreamSource",
-    "Windowed",
-    "stream",
-    "windowed",
-]
